@@ -179,7 +179,8 @@ chat_connection_changed_cb (EmpathyAccountManager *manager,
 
 	if (current == TP_CONNECTION_STATUS_CONNECTED && !priv->tp_chat &&
 	    empathy_account_equal (account, priv->account) &&
-	    priv->handle_type != TP_HANDLE_TYPE_NONE) {
+	    priv->handle_type != TP_HANDLE_TYPE_NONE &&
+	    !EMP_STR_EMPTY (priv->id)) {
 		
 		DEBUG ("Account reconnected, request a new Text channel");
 
@@ -1244,6 +1245,7 @@ chat_destroy_cb (EmpathyTpChat *tp_chat,
 		return;
 	}
 
+	chat_composing_remove_timeout (chat);
 	g_object_unref (priv->tp_chat);
 	priv->tp_chat = NULL;
 	g_object_notify (G_OBJECT (chat), "tp-chat");
